import { request } from 'umi';

/** 获取设备列表  */
export async function GetDeviceInfoPage(data) {
     return request(`/kitchen/api/Device/GetDeviceInfoPage`, {
      method: 'POST',
      data: data,
    });
  }
  /**获取设备类型 */
  export async function GetDicList(TypeCode) {
    return request(`/kitchen/api/dict-data/dic-list/${TypeCode}`, {
      method: 'Get',
    });
 }
  /** 添加设备  */
export async function AddDeviceInfo(data) {
    return request(`/kitchen/api/Device/AddDeviceInfo`, {
     method: 'POST',
     data: data,
   });
 }

/** 修改  */
export async function UpdateDeviceInfo(data) {
    return request(`/kitchen/api/Device/UpdateDeviceInfo`, {
     method: 'POST',
     data: data,
   });
 }
/** 修改  */
export async function CopyDevice(data) {
  return request(`/kitchen/api/Device/CopyDevice`, {
   method: 'POST',
   data: data,
 });
}
   /** 删除  */
export async function DelDeviceInfo(data) {
    return request(`​​/kitchen/api/Device/DelDeviceInfo`, {
     method: 'POST',
     data: data,
   });
 }
   /** 获取所有设备类型  */
   export async function GetDeviceType(data) {
    return request(`​/kitchen/api/Device/GetDeviceType`, {
     method: 'GET',
   });
  }

    /** 获取所有设备版本  */
    export async function GetDeviceVersions() {
      return request(`​/kitchen/api/Device/GetDeviceVersions`, {
       method: 'post',
     });
    }

